@@ -1,26 +1,26 @@
 /*
  * SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
- * 
+ *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #pragma once
 
-#include <memory>
 #include <QAbstractListModel>
 #include <QQmlParserStatus>
+#include <memory>
 
 class PageDataObject;
 
 class PageDataModel : public QAbstractListModel
 {
     Q_OBJECT
-//     Q_INTERFACES(QQmlParserStatus)
+    //     Q_INTERFACES(QQmlParserStatus)
     Q_PROPERTY(PageDataObject *data READ dataObject WRITE setDataObject NOTIFY dataObjectChanged)
 
 public:
     enum Roles {
-        DataRole = Qt::UserRole + 1
+        DataRole = Qt::UserRole + 1,
     };
     Q_ENUM(Roles)
 
@@ -37,8 +37,8 @@ public:
 
     Q_INVOKABLE int countObjects(const QVariantMap &properties);
 
-//     void classBegin() override;
-//     void componentComplete() override;
+    //     void classBegin() override;
+    //     void componentComplete() override;
 
 private:
     PageDataObject *m_data = nullptr;
